---
name: Bug report
about: Create a bug report to help improve the ONNX.
title: ''
labels: 'bug'
assignees: ''

---
# Bug Report

### Is the issue related to model conversion?
If the ONNX checker reports issues with this model then this is most probably related to the converter used to convert the original framework model to ONNX. Please create this bug in the appropriate converter's GitHub repo (pytorch, tensorflow-onnx, sklearn-onnx, keras-onnx, onnxmltools) to get the best help.

### Describe the bug
Please describe the bug clearly and concisely

### System information
- OS Platform and Distribution (*e.g. Linux Ubuntu 16.04*): 
- ONNX version (*e.g. 1.7*):  
- Python version:
- GCC/Compiler version (if compiling from source):
- CMake version:
- Protobuf version:
- Visual Studio version (if applicable):


### Reproduction instructions
- Describe the code to reproduce the behavior.
```
import onnx
model = onnx.load('model.onnx')
...
```
- Attach the ONNX model to the issue (where applicable)

### Expected behavior
A clear and concise description of what you expected to happen.

### Notes

Any additional information
